chitose.app.bsky.richtext package
=================================

Submodules
----------

chitose.app.bsky.richtext.facet module
--------------------------------------

.. automodule:: chitose.app.bsky.richtext.facet
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: chitose.app.bsky.richtext
   :members:
   :undoc-members:
   :show-inheritance:
